from gnani_voicebiometric_api.log_config import logger
from gnani_voicebiometric_api.utils import voicebiometric_service
from gnani_voicebiometric_api import enroll
from gnani_voicebiometric_api import authenticate
from gnani_voicebiometric_api import disenroll


import json
import requests

from gnani_voicebiometric_api.log_config.logger import get_logger

logger = get_logger(__name__)


def voicebiometric_service(api_url, request_headers, request_payload, files={}):
    """ Method to send text and get converted audio string in response
        Args:
            request_headers (json): request headers
            request_payload (json): request payload
        Raises:
            Exceptions
        Returns:
            response: Response from the server
    """
    try:
        response = requests.request("POST", api_url, headers=request_headers, data=request_payload, files=files)

        return response.json()

    except BaseException as exception:
        logger.exception('Exception in getting voicebiometric !' + str(exception))
        return {"message": "Something went wrong","status":"fail"}



from configparser import ConfigParser
from armour365.log_config.logger import get_logger
from armour365.utils import voicebiometric_service

import os

current_dir = os.getcwd()

logger = get_logger(__name__)

# Reading from config file
parser = ConfigParser()
parser.read('user.config')

enroll_api_url = "https://armour365.gnani.ai/api/enrollment"

def start():
    """ Set all below parameters in the config file. """
    # certificate = input("Enter the name of the certificate with extention: ")
    # cert = current_dir + "/" + certificate
    token = input("Enter Token: ")
    accesskey = input("Enter AccessKey: ")
    audio_name = input("Enter the full name of the audiofile with extention: ")
    audio_file = current_dir + "/" + audio_name

    speaker = input("Enter Speaker's name: ")
    userid = input("Enter Email ID: ")
    try:
        logger.info("Enrollment Method ! - Start")

        # construct request headers
        headers = {
            "product": "voice-biometric",
            "token": token,
            "accesskey": accesskey,
            "userid": userid
        }

        # construct request payload
        payload = {'speaker': speaker}

        files = {'audio_file': open(audio_file, 'rb')}

        """
            Request Gnani VoiceBiometric Service to enroll your voice
        """
        response = voicebiometric_service(enroll_api_url, headers, payload, files)
        logger.info("Response from VoiceBiometric server : {}".format(response))
        logger.info("Enrollment Method ! - End")

    except BaseException as e:
        logger.exception(e)
        logger.info("Exception in main method !")


if __name__ == '__main__':
    start()



from setuptools import setup, find_packages

VERSION = '1.0'
DESCRIPTION = 'armour365'
LONG_DESCRIPTION = 'This is a voicebiometric api to authenticate your voice with gnani VoiceBiometric service'

# Setting up
setup(
       # the name must match the folder name 'verysimplemodule'
        name="armour365",
        version=VERSION,
        author="gnani.ai",
        author_email="<api.service@gnani.ai>",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        packages=find_packages(),
        package_data={'armour365.audio': ['*.wav'], 'armour365': ['*.pem', '*.md','*.log']},
        include_package_data=True,
        install_requires=['requests','pytz'],
        keywords=['python', 'Voicebiometric service'],
        classifiers= [
            "Development Status :: 3 - Alpha",
            "Intended Audience :: Education",
            "Programming Language :: Python :: 2",
            "Programming Language :: Python :: 3",
            "Operating System :: MacOS :: MacOS X",
            "Operating System :: Microsoft :: Windows",
        ]
)



import logging.handlers
import logging
import sys
from pytz import timezone, utc
from datetime import datetime


def custom_time(*args):
    """
    get the customised time
    :return:
    """
    utc_dt = utc.localize(datetime.utcnow())
    my_tz = timezone("Asia/Kolkata")
    converted = utc_dt.astimezone(my_tz)
    return converted.timetuple()


def get_logger(name):
    """
    get the customised logger for the given python file
    :param name:
    :return:
    """
    logger = logging.getLogger(name)
    logger.setLevel("DEBUG")
    logging.Formatter.converter = custom_time
    handler = logging.StreamHandler(sys.stdout)
    handler.setFormatter(
        logging.Formatter('%(asctime)s — %(name)s — %(levelname)s - %(process)d - %(thread)d — %(funcName)s:%(lineno)d '
                          '— %(message)s'))
    logger.addHandler(handler)
    return logger
